@@ -8,9 +8,10 @@ from json import dump
 
 class fsonbase:
     def __init__(self, filepath):
+        filepath = filepath.replace('\\', '/')
         if isdir(filepath):
             self.filepath = filepath
-            self.clusters = tuple([fcluster(fr"{self.filepath}\{x}").name for x in listdir(self.filepath) if Path(x).suffix == '.json'])
+            self.clusters = tuple([fcluster(fr"{self.filepath}/{x}").name for x in listdir(self.filepath) if Path(x).suffix == '.json'])
         else:
             raise TypeError("Invalid filepath. Should be directory")
 
